
Change Log
----------


0.1.9 (2017.07.06)
^^^^^^^^^^^^^^^^^^

* NLP moran NER
* NLP thulac segment
* NLP thulac postag


0.1.8 (2017.06.26)
^^^^^^^^^^^^^^^^^^

* NLP moran segment
* NLP moran postag


0.1.7 (2017.06.20)
^^^^^^^^^^^^^^^^^^

* NLP jieba segment
* NLP LTP segment
* NLP jieba POSTag
* NLP LTP POSTag
* NLP LTP NER
* NLP LTP Dependecy Parse
* NLP LTP Semantic Role Labeling


0.1.6 (2017.06.19)
^^^^^^^^^^^^^^^^^^

* Hanzi Converter
* Chinese Stopwords

